pycocoa.octypes.NSRect4_t

Package pycocoa :: Module octypes :: Class NSRect4_t |
[frames] | no frames]

# Class NSRect4_t

       object --+
                |
        ??._CData --+
                    |
    _ctypes.Structure --+
                        |
               c_struct_t --+
                            |
                     NSRect_t --+
                                |
                               NSRect4_t

ObjC `struct`, like NSRect_t with different signature and properties.

Instance Methods
__init__(self, x=0, y=0, width=0, height=0) x.__init__(...) initializes x; see help(type(x)) for signature |
__repr__(self) repr(x) |
__str__(self) str(x) |
Inherited from `_ctypes.Structure`: `__new__` Inherited from `_CData`: `__ctypes_from_outparam__`, `__hash__`, `__reduce__`, `__setstate__` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables
Inherited from `NSRect_t`: `origin`, `size`

Properties
| bottom Get the bottom y coordinate (`float`).
| height Get the height (`float`).
| left Get the lower x coordinate (`float`).
| right Get the upper x coordinate (`float`).
| top Get the upper y coordinate (`float`).
| width Get the width (`float`).
| x Get the x coordinate (`float`).
| y Get the y coordinate (`float`).
Inherited from `object`: `__class__`

Method Details

### __init__(self, x=0, y=0, width=0, height=0) (Constructor) |
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

### __repr__(self) (Representation operator) |
repr(x) Overrides: object.__repr__ (inherited documentation)

### __str__(self) (Informal representation operator) |
str(x) Overrides: object.__str__ (inherited documentation)

Property Details

### bottom Get the bottom y coordinate (`float`). Get Method: bottom(self) - Get the bottom y coordinate (`float`). Set Method: Read_Only(inst, value) - Throws an `AttributeError`, always.

### height Get the height (`float`). Get Method: height(self) - Get the height (`float`). Set Method: Read_Only(inst, value) - Throws an `AttributeError`, always.

### left Get the lower x coordinate (`float`). Get Method: left(self) - Get the lower x coordinate (`float`). Set Method: Read_Only(inst, value) - Throws an `AttributeError`, always.

### right Get the upper x coordinate (`float`). Get Method: right(self) - Get the upper x coordinate (`float`). Set Method: Read_Only(inst, value) - Throws an `AttributeError`, always.

### top Get the upper y coordinate (`float`). Get Method: top(self) - Get the upper y coordinate (`float`). Set Method: Read_Only(inst, value) - Throws an `AttributeError`, always.

### width Get the width (`float`). Get Method: width(self) - Get the width (`float`). Set Method: Read_Only(inst, value) - Throws an `AttributeError`, always.

### x Get the x coordinate (`float`). Get Method: x(self) - Get the x coordinate (`float`). Set Method: Read_Only(inst, value) - Throws an `AttributeError`, always.

### y Get the y coordinate (`float`). Get Method: y(self) - Get the y coordinate (`float`). Set Method: Read_Only(inst, value) - Throws an `AttributeError`, always.